==> hoa_1.1-1.tar.gz: hoa/nlreg/man/nlreg-package.Rd <==
\name{nlreg-package}
\alias{nlreg-package}
\docType{package}
\title{
Higher Order Inference for Nonlinear Heteroscedastic Models
}
\description{
Likelihood inference based on higher order approximations
for nonlinear models with possibly non constant variance
}
\details{
\tabular{ll}{
Package: \tab nlreg\cr
Version: \tab 1.0-0\cr
Date: \tab 2005-05-31\cr
LazyLoad: \tab yes\cr
LazyData: \tab yes\cr
Bundle: \tab hoa\cr
BundleDescription: \tab Various functions for higher order likelihood-based
inference\cr
Contains: \tab cond marg nlreg csampling\cr
Depends: \tab R (>= 2.0.1), statmod, survival\cr
License: \tab GPL (version 2 or later)\cr
URL: \tab http://www.r-project.org, http://www.isib.cnr.it/~brazzale/CS/\cr
Packaged: \tab Thu Nov 24 11:57:28 2005; brazzale\cr
Built: \tab R 2.2.0; ; 2005-11-24 12:35:44; unix\cr
}

Index:
\preformatted{
Functions:
=========
Dmean                   Differentiate the Mean Function of a Nonlinear
                        Model
Dvar                    Differentiate the Variance Function of a
                        Nonlinear Model
contour.all.nlreg.profiles
                        Contour Method for 'nlreg' Objects
expInfo                 Returns the Expected Information Matrix --
                        Generic Function
expInfo.nlreg           Expected Information Matrix for 'nlreg'
                        Objects
logLik.nlreg            Compute the Log Likelihood for Nonlinear
                        Heteroscedastic Models
mpl                     Maximum Adjusted Profile Likelihood Estimation
                        -- Generic Function
mpl.nlreg               Maximum Adjusted Profile Likelihood Estimates
                        for a 'nlreg' Object
mpl.object              Maximum Adjusted Profile Likelihood Object
nlreg                   Fit a Nonlinear Heteroscedastic Model via
                        Maximum Likelihood
nlreg.diag              Nonlinear Heteroscedastic Model Diagnostics
nlreg.object            Nonlinear Heteroscedastic Model Object
obsInfo                 Returns the Observed Information Matrix --
                        Generic Function
obsInfo.nlreg           Observed Information Matrix for 'nlreg'
                        Objects
param                   Extract All Parameters from a Model -- Generic
                        Function
plot.nlreg.contours     Use plot() on a 'nlreg.contours' object
plot.nlreg.diag         Diagnostic Plots for Nonlinear Heteroscedastic
                        Models
plot.nlreg.profile      Use plot() on a 'profile.nlreg' and
                        'all.profiles.nlreg' object
profile.nlreg           Profile Method for 'nlreg' Objects
summary.all.nlreg.profiles
                        Summary Method for Objects of Class
                        'all.nlreg.profiles'
summary.mpl             Summary Method for 'mpl' Objects
summary.nlreg           Summary Method for Nonlinear Heteroscedastic
                        Models
summary.nlreg.profile   Summary Method for Objects of Class
                        'nlreg.profile'
var2cor                 Convert Covariance Matrix to Correlation
                        Matrix -- Generic Function


Datasets:
========
chlorsulfuron           Chlorsulfuron Data
daphnia                 'Daphnia Magna' Data
metsulfuron             Metsulfuron Methyl Data
ria                     Radioimmunoassay Data
}

Further information is available in the following vignettes:
\tabular{ll}{
\code{Rnews-paper} \tab hoa: An R Package Bundle for Higher Order Likelihood Inference (source, pdf)\cr
}
}
\author{
S original by Alessandra R. Brazzale
<alessandra.brazzale@isib.cnr.it> and Ruggero Bellio
<ruggero.bellio@dss.uniud.it>.  R port by Alessandra R.
Brazzale <alessandra.brazzale@isib.cnr.it>, following earlier
work by Douglas Bates.

Maintainer: Alessandra R. Brazzale <alessandra.brazzale@isib.cnr.it>
}
\references{
}
\keyword{ package }
\seealso{
}
\examples{
}

==> hoa_1.1-2.tar.gz: hoa/nlreg/man/nlreg-package.Rd <==
\name{nlreg-package}
\alias{nlreg-package}
\docType{package}
\title{
Higher Order Inference for Nonlinear Heteroscedastic Models
}
\description{
Likelihood inference based on higher order approximations
for nonlinear models with possibly non constant variance
}
\details{
\tabular{ll}{
Package: \tab nlreg\cr
Version: \tab 1.0-0\cr
Date: \tab 2005-05-31\cr
LazyLoad: \tab yes\cr
LazyData: \tab yes\cr
Bundle: \tab hoa\cr
BundleDescription: \tab Various functions for higher order likelihood-based
inference\cr
Contains: \tab cond marg nlreg csampling\cr
Depends: \tab R (>= 2.0.1), statmod, survival\cr
License: \tab GPL (version 2 or later)\cr
URL: \tab http://www.r-project.org, http://www.isib.cnr.it/~brazzale/CS/\cr
Packaged: \tab Thu Nov 24 11:57:28 2005; brazzale\cr
Built: \tab R 2.2.0; ; 2005-11-24 12:35:44; unix\cr
}

Index:
\preformatted{
Functions:
=========
Dmean                   Differentiate the Mean Function of a Nonlinear
                        Model
Dvar                    Differentiate the Variance Function of a
                        Nonlinear Model
contour.all.nlreg.profiles
                        Contour Method for 'nlreg' Objects
expInfo                 Returns the Expected Information Matrix --
                        Generic Function
expInfo.nlreg           Expected Information Matrix for 'nlreg'
                        Objects
logLik.nlreg            Compute the Log Likelihood for Nonlinear
                        Heteroscedastic Models
mpl                     Maximum Adjusted Profile Likelihood Estimation
                        -- Generic Function
mpl.nlreg               Maximum Adjusted Profile Likelihood Estimates
                        for a 'nlreg' Object
mpl.object              Maximum Adjusted Profile Likelihood Object
nlreg                   Fit a Nonlinear Heteroscedastic Model via
                        Maximum Likelihood
nlreg.diag              Nonlinear Heteroscedastic Model Diagnostics
nlreg.object            Nonlinear Heteroscedastic Model Object
obsInfo                 Returns the Observed Information Matrix --
                        Generic Function
obsInfo.nlreg           Observed Information Matrix for 'nlreg'
                        Objects
param                   Extract All Parameters from a Model -- Generic
                        Function
plot.nlreg.contours     Use plot() on a 'nlreg.contours' object
plot.nlreg.diag         Diagnostic Plots for Nonlinear Heteroscedastic
                        Models
plot.nlreg.profile      Use plot() on a 'profile.nlreg' and
                        'all.profiles.nlreg' object
profile.nlreg           Profile Method for 'nlreg' Objects
summary.all.nlreg.profiles
                        Summary Method for Objects of Class
                        'all.nlreg.profiles'
summary.mpl             Summary Method for 'mpl' Objects
summary.nlreg           Summary Method for Nonlinear Heteroscedastic
                        Models
summary.nlreg.profile   Summary Method for Objects of Class
                        'nlreg.profile'
var2cor                 Convert Covariance Matrix to Correlation
                        Matrix -- Generic Function


Datasets:
========
chlorsulfuron           Chlorsulfuron Data
daphnia                 'Daphnia Magna' Data
metsulfuron             Metsulfuron Methyl Data
ria                     Radioimmunoassay Data
}

Further information is available in the following vignettes:
\tabular{ll}{
\code{Rnews-paper} \tab hoa: An R Package Bundle for Higher Order Likelihood Inference (source, pdf)\cr
}
}
\author{
S original by Alessandra R. Brazzale <alessandra.brazzale@unimore.it> 
and Ruggero Bellio <ruggero.bellio@dss.uniud.it>.  R port by Alessandra R.
Brazzale <alessandra.brazzale@unimore.it>, following earlier work by 
Douglas Bates.

Maintainer: Alessandra R. Brazzale <alessandra.brazzale@unimore.it>
}
\references{
}
\keyword{ package }
\seealso{
}
\examples{
}
